"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createProducer = void 0;
const util_1 = require("util");
const winston_1 = __importDefault(require("winston"));
const server_services_ordering_kafkanode_1 = require("@fluidframework/server-services-ordering-kafkanode");
const server_services_ordering_rdkafka_1 = require("@fluidframework/server-services-ordering-rdkafka");
const server_services_telemetry_1 = require("@fluidframework/server-services-telemetry");
// Kafka has an internal limit of 1Mb.
// Runtime has a client-imposed limit of 768kb.
// Set our enforced limit at 900kb to give space for any
// mysterious overhead.
const MaxKafkaMessageSize = 900 * 1024;
function createProducer(type, kafkaEndPoint, clientId, topic, enableIdempotence, pollIntervalMs, numberOfPartitions, replicationFactor, maxBatchSize, sslCACertFilePath) {
    let producer;
    if (type === "rdkafka") {
        producer = new server_services_ordering_rdkafka_1.RdkafkaProducer({ kafka: [kafkaEndPoint] }, clientId, topic, {
            enableIdempotence,
            pollIntervalMs,
            numberOfPartitions,
            replicationFactor,
            maxBatchSize,
            maxMessageSize: MaxKafkaMessageSize,
            sslCACertFilePath,
        });
        producer.on("error", (error, errorData) => {
            if (errorData === null || errorData === void 0 ? void 0 : errorData.restart) {
                throw new Error(error);
            }
            else {
                winston_1.default.error("Kafka Producer emitted an error that is not configured to restart the process.");
                winston_1.default.error((0, util_1.inspect)(error));
                server_services_telemetry_1.Lumberjack.error("Kafka Producer emitted an error that is not configured to restart the process.", undefined, error);
            }
        });
    }
    else {
        producer = new server_services_ordering_kafkanode_1.KafkaNodeProducer({ kafkaHost: kafkaEndPoint }, clientId, topic, numberOfPartitions, replicationFactor, maxBatchSize, MaxKafkaMessageSize);
        producer.on("error", (error) => {
            winston_1.default.error(error);
            server_services_telemetry_1.Lumberjack.error(error);
        });
    }
    return producer;
}
exports.createProducer = createProducer;
//# sourceMappingURL=kafkaProducerFactory.js.map