/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IClient, ISignalClient } from "@fluidframework/protocol-definitions";
import { IClientManager, ISequencedSignalClient } from "@fluidframework/server-services-core";
import { IRedisParameters } from "@fluidframework/server-services-utils";
import { Redis } from "ioredis";
export declare class ClientManager implements IClientManager {
    private readonly client;
    private readonly expireAfterSeconds;
    private readonly prefix;
    constructor(client: Redis, parameters?: IRedisParameters);
    addClient(tenantId: string, documentId: string, clientId: string, details: IClient): Promise<void>;
    removeClient(tenantId: string, documentId: string, clientId: string): Promise<void>;
    getClients(tenantId: string, documentId: string): Promise<ISignalClient[]>;
    /**
     * Returns all clients currently connected including a keep alive time.
     * Should be used with delis read only client functionality.
     */
    getSequencedClients(tenantId: string, documentId: string): Promise<Map<string, ISequencedSignalClient>>;
    /**
     * Called when the expiration time of clients should be extended.
     * @param clientTimeout - Amount of time in milliseconds to add to the clients expiration time.
     */
    extendSequencedClients(tenantId: string, documentId: string, clients: Map<string, ISequencedSignalClient>, clientTimeout: number): Promise<void>;
    private getKey;
}
//# sourceMappingURL=redisClientManager.d.ts.map