/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IThrottler, IThrottlerHelper, ILogger, IUsageData } from "@fluidframework/server-services-core";
/**
 * A lenient implementation of IThrottlerHelper that prioritizes low latency over strict throttling.
 * This should be used for implementing throttling in places where latency matters more than accuracy,
 * such as service endpoints or socket connections.
 */
export declare class Throttler implements IThrottler {
    private readonly throttlerHelper;
    private readonly minThrottleIntervalInMs;
    private readonly logger?;
    private readonly lastThrottleUpdateAtMap;
    private readonly countDeltaMap;
    private readonly throttlerResponseCache;
    constructor(throttlerHelper: IThrottlerHelper, minThrottleIntervalInMs?: number, logger?: ILogger, maxCacheSize?: number, maxCacheAge?: number);
    /**
     * Increments operation count and calculates throttle status of given operation id.
     * Uses most recently calculated throttle status to determine current throttling, while updating in the background.
     * @throws {@link ThrottlingError} if throttled
     */
    incrementCount(id: string, weight?: number, usageStorageId?: string, usageData?: IUsageData): void;
    /**
     * Decrements operation count of given operation id.
     */
    decrementCount(id: string, weight?: number): void;
    private updateCountDelta;
    private updateAndCacheThrottleStatus;
}
//# sourceMappingURL=throttler.d.ts.map